//
// Copyright (c) 2012, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;
using Antlr.Runtime;
using MindFusion.Drawing;
using MindFusion.Diagramming.Layout;


namespace MindFusion.Diagramming.WinForms.Samples.CS.JavaScript
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        private void btnLoad_Click(object sender, EventArgs e)
        {
            OpenFileDialog dialog = new OpenFileDialog();

            dialog.Filter = "JavaScript Files (*.js)|*.js|All Files|*.*||";
            if (dialog.ShowDialog(this) == DialogResult.OK)
            {
                try
                {
                    using (StreamReader r = new StreamReader(dialog.FileName))
                        tbCode.Text = r.ReadToEnd();
                }
                catch (IOException ex)
                {
                    MessageBox.Show(ex.Message);
                }
            }
        }

        private void btnParse_Click(object sender, EventArgs e)
        {
            ANTLRReaderStream rs = new ANTLRReaderStream(new StringReader(tbCode.Text));
            JavaScriptLexer lexer = new JavaScriptLexer(rs);
            CommonTokenStream tokens = new CommonTokenStream(lexer);
            JavaScriptParser parser = new JavaScriptParser(tokens);

            Logger logger = new Logger(parser);
            SyntaxTreeBuilder syntaxTreeBuilder = new SyntaxTreeBuilder(parser, syntaxTree);
            FlowchartBuilder flowchartBuilder = new FlowchartBuilder(parser, flowchart);

            try
            {
                parser.program();
            }
            catch (InvalidOperationException)
            {
                MessageBox.Show("Failed to parse input.");
            }

            TreeLayout layout = new TreeLayout();
            layout.Arrange(syntaxTree);
            syntaxTree.ResizeToFitItems(10);

            FlowchartLayout l = new FlowchartLayout();
            l.Orientation = MindFusion.Diagramming.Layout.Orientation.Vertical;
            l.Arrange(flowchart);
            flowchart.ResizeToFitItems(10);
        }

        private void DrawLabel(IGraphics g, string text, Font font, float x, float y)
        {
            SizeF size = g.MeasureString(text, font);
            RectangleF r = new RectangleF(x + 2, y + 2, size.Width, size.Height);

            using (System.Drawing.Brush brush = new System.Drawing.SolidBrush(Color.FromArgb(240, 248, 255)))
                g.FillRectangle(brush, r);
            using (System.Drawing.Pen pen = new System.Drawing.Pen(Color.LightSteelBlue, 0))
                g.DrawRectangle(pen, r.X, r.Y, r.Width, r.Height);
            g.DrawString(text, font, Brushes.DimGray, x + 2, y + 2);
        }

        private void syntaxTree_DrawBackground(object sender, MindFusion.Diagramming.DiagramEventArgs e)
        {
            DrawLabel(e.Graphics, "Code Syntax Tree", DefaultFont,
                diagramView1.ScrollX, diagramView1.ScrollY);
        }

        private void flowchart_DrawBackground(object sender, MindFusion.Diagramming.DiagramEventArgs e)
        {
            DrawLabel(e.Graphics, "Code Flowchart", DefaultFont,
                diagramView2.ScrollX, diagramView2.ScrollY);
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
            if (File.Exists("QuickSort.js"))
            {
                using (StreamReader reader = new StreamReader("QuickSort.js"))
                {
                    tbCode.Text = reader.ReadToEnd();
                    tbCode.Select(0, 0);
                }
            }
        }


		private Font DefaultFont = new Font("Microsoft Sans Serif", 3, FontStyle.Regular, GraphicsUnit.World);
    }
}