﻿//
// Copyright (c) 2012, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;


namespace MindFusion.Diagramming.WinForms.Samples.CS.JavaScript
{
	static class Notation
	{
		public static ShapeNode CreateStartTerminatorNode(Diagram diagram, string text)
		{
			ShapeNode node = diagram.Factory.CreateShapeNode(0, 0, 30, 10);
			node.Shape = Shapes.RoundRect;
            node.Brush = CreateGradientBrush(Color.FromArgb(0, 0, 99));
			node.Font = new Font(node.EffectiveFont, FontStyle.Bold);
			node.Text = text;
			node.ToolTip = text;
			node.TextFormat.FormatFlags |= StringFormatFlags.NoWrap;

			return node;
		}

		public static ShapeNode CreateEndTerminatorNode(Diagram diagram, string text)
		{
			ShapeNode node = diagram.Factory.CreateShapeNode(0, 0, 30, 10);
			node.Shape = Shapes.RoundRect;
            node.Brush = CreateGradientBrush(Color.FromArgb(206, 0, 0));
			node.Font = new Font(node.EffectiveFont, FontStyle.Bold);
			node.Text = text;
			node.ToolTip = text;
			node.TextFormat.FormatFlags |= StringFormatFlags.NoWrap;

			return node;
		}

		public static ShapeNode CreateConnectorNode(Diagram diagram, string text)
		{
			ShapeNode node = diagram.Factory.CreateShapeNode(0, 0, 5, 5);
			node.Shape = Shapes.Ellipse;
			node.Brush = CreateGradientBrush(Color.White);
			node.Text = text;
			node.ToolTip = text;
			node.TextFormat.FormatFlags |= StringFormatFlags.NoWrap;

			return node;
		}

		public static ShapeNode CreateProcessNode(Diagram diagram, string text)
		{
			ShapeNode node = diagram.Factory.CreateShapeNode(0, 0, 30, 10);
			node.Shape = Shapes.Rectangle;
            node.Brush = CreateGradientBrush(Color.FromArgb(97, 106, 127));
			node.Text = text;
			node.ToolTip = text;
			node.TextFormat.FormatFlags |= StringFormatFlags.NoWrap;

			return node;
		}

		public static ShapeNode CreateDecisionNode(Diagram diagram, string text)
		{
			ShapeNode node = diagram.Factory.CreateShapeNode(0, 0, 30, 10);
			node.Shape = Shapes.Decision;
			node.Brush = CreateGradientBrush(Color.FromArgb(192, 192, 192));
			node.Text = text;
			node.ToolTip = text;
			node.TextFormat.FormatFlags |= StringFormatFlags.NoWrap;

			return node;
		}

		public static ShapeNode CreateLoopNode(Diagram diagram, string text)
		{
			ShapeNode node = diagram.Factory.CreateShapeNode(0, 0, 30, 10);
			node.Shape = Shapes.BeginLoop;
			node.Brush = CreateGradientBrush(Color.Goldenrod);
			node.Text = text;
			node.ToolTip = text;
			node.TextFormat.FormatFlags |= StringFormatFlags.NoWrap;

			return node;
		}

		public static ShapeNode CreateEndLoopNode(Diagram diagram, string text)
		{
			ShapeNode node = diagram.Factory.CreateShapeNode(0, 0, 30, 10);
			node.Shape = Shapes.EndLoop;
			node.Brush = CreateGradientBrush(Color.Goldenrod);
			node.Text = text;
			node.ToolTip = text;
			node.TextFormat.FormatFlags |= StringFormatFlags.NoWrap;

			return node;
		}


		private static MindFusion.Drawing.LinearGradientBrush CreateGradientBrush(Color color)
		{
			MindFusion.Drawing.LinearGradientBrush brush =
				new MindFusion.Drawing.LinearGradientBrush(Color.Empty, Color.Empty);

			System.Drawing.Drawing2D.ColorBlend blend =
				new System.Drawing.Drawing2D.ColorBlend(3);

			blend.Colors = new Color[] { color, Color.White, color };
			blend.Positions = new float[] { 0f, 0.5f, 1f };

			brush.InterpolationColors = blend;
			brush.Angle = 90;

			return brush;
		}
	}
}
